from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.FhirValueSetBase import FhirValueSetBase
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class AuditEventEntityRoleCode(FhirValueSetBase):
    """
    AuditEventEntityRole
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/ValueSet/object-role
    """
    codeset: FhirUri = "http://hl7.org/fhir/ValueSet/object-role"


class AuditEventEntityRoleCodeValues:
    """
    This object is the patient that is the subject of care related to this event.  It is identifiable by patient ID or equivalent.  The patient may be either human or animal.
    """

    Patient = AuditEventEntityRoleCode("1")
    """
    This is a location identified as related to the event.  This is usually the location where the event took place.  Note that for shipping, the usual events are arrival at a location or departure from a location.
    """
    Location = AuditEventEntityRoleCode("2")
    """
    This object is any kind of persistent document created as a result of the event.  This could be a paper report, film, electronic report, DICOM Study, etc.  Issues related to medical records life cycle management are conveyed elsewhere.
    """
    Report = AuditEventEntityRoleCode("3")
    """
    A logical object related to a health record event.  This is any healthcare  specific resource (object) not restricted to FHIR defined Resources.
    """
    DomainResource = AuditEventEntityRoleCode("4")
    """
    This is any configurable file used to control creation of documents.  Examples include the objects maintained by the HL7 Master File transactions, Value Sets, etc.
    """
    MasterFile = AuditEventEntityRoleCode("5")
    """
    A human participant not otherwise identified by some other category.
    """
    User = AuditEventEntityRoleCode("6")
    """
    (deprecated).
    """
    List_ = AuditEventEntityRoleCode("7")
    """
    Typically, a licensed person who is providing or performing care related to the event, generally a physician.   The key distinction between doctor and practitioner is with regards to their role, not the licensing.  The doctor is the human who actually performed the work.  The practitioner is the human or organization that is responsible for the work.
    """
    Doctor = AuditEventEntityRoleCode("8")
    """
    A person or system that is being notified as part of the event.  This is relevant in situations where automated systems provide notifications to other parties when an event took place.
    """
    Subscriber = AuditEventEntityRoleCode("9")
    """
    Insurance company, or any other organization who accepts responsibility for paying for the healthcare event.
    """
    Guarantor = AuditEventEntityRoleCode("10")
    """
    A person or active system object involved in the event with a security role.
    """
    SecurityUserEntity = AuditEventEntityRoleCode("11")
    """
    A person or system object involved in the event with the authority to modify security roles of other objects.
    """
    SecurityUserGroup = AuditEventEntityRoleCode("12")
    """
    A passive object, such as a role table, that is relevant to the event.
    """
    SecurityResource = AuditEventEntityRoleCode("13")
    """
    (deprecated)  Relevant to certain RBAC security methodologies.
    """
    SecurityGranularityDefinition = AuditEventEntityRoleCode("14")
    """
    Any person or organization responsible for providing care.  This encompasses all forms of care, licensed or otherwise, and all sorts of teams and care groups. Note the distinction between practitioner and the doctor that actually provided the care to the patient.
    """
    Practitioner = AuditEventEntityRoleCode("15")
    """
    The source or destination for data transfer, when it does not match some other role.
    """
    DataDestination = AuditEventEntityRoleCode("16")
    """
    A source or destination for data transfer that acts as an archive, database, or similar role.
    """
    DataRepository = AuditEventEntityRoleCode("17")
    """
    An object that holds schedule information.  This could be an appointment book, availability information, etc.
    """
    Schedule = AuditEventEntityRoleCode("18")
    """
    An organization or person that is the recipient of services.  This could be an organization that is buying services for a patient, or a person that is buying services for an animal.
    """
    Customer = AuditEventEntityRoleCode("19")
    """
    An order, task, work item, procedure step, or other description of work to be performed; e.g. a particular instance of an MPPS.
    """
    Job = AuditEventEntityRoleCode("20")
    """
    A list of jobs or a system that provides lists of jobs; e.g. an MWL SCP.
    """
    JobStream = AuditEventEntityRoleCode("21")
    """
    (Deprecated).
    """
    Table = AuditEventEntityRoleCode("22")
    """
    An object that specifies or controls the routing or delivery of items.  For example, a distribution list is the routing criteria for mail.  The items delivered may be documents, jobs, or other objects.
    """
    RoutingCriteria = AuditEventEntityRoleCode("23")
    """
    The contents of a query.  This is used to capture the contents of any kind of query.  For security surveillance purposes knowing the queries being made is very important.
    """
    Query = AuditEventEntityRoleCode("24")
