from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.FhirValueSetBase import FhirValueSetBase
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class ImmunizationStatusReasonCodesCode(FhirValueSetBase):
    """
    ImmunizationStatusReasonCodes
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/ValueSet/immunization-status-reason
    """
    codeset: FhirUri = "http://hl7.org/fhir/ValueSet/immunization-status-reason"


class ImmunizationStatusReasonCodesCodeValues:
    """
    Identifies the reason the patient is assigned to this accommodation type
    """

    Actaccommodationreason = ImmunizationStatusReasonCodesCode(
        "_ActAccommodationReason"
    )
    """
    Description:Codes used to specify reasons or criteria relating to coverage provided under a policy or program.  May be used to convey reasons pertaining to coverage contractual provisions, including criteria for eligibility, coverage limitations, coverage maximums, or financial participation required of covered parties.
    """
    Actcoveragereason = ImmunizationStatusReasonCodesCode("_ActCoverageReason")
    """
    Description:The rationale or purpose for an act relating to information management, such as archiving information for the purpose of complying with an enterprise data retention policy.
    """
    Actinformationmanagementreason = ImmunizationStatusReasonCodesCode(
        "_ActInformationManagementReason"
    )
    """
    Description: Types of reasons why a substance is invalid for use.
    """
    Actinvalidreason = ImmunizationStatusReasonCodesCode("_ActInvalidReason")
    """
    Domain specifies the codes used to describe reasons why a Provider is cancelling an Invoice or Invoice Grouping.
    """
    Actinvoicecancelreason = ImmunizationStatusReasonCodesCode(
        "_ActInvoiceCancelReason"
    )
    """
    A coded description of the reason for why a patient did not receive a scheduled immunization.

                        (important for public health strategy
    """
    Actnoimmunizationreason = ImmunizationStatusReasonCodesCode(
        "_ActNoImmunizationReason"
    )
    """
    Indicates why a fulfiller refused to fulfill a supply order, and considered it important to notify other providers of their decision.  E.g. "Suspect fraud", "Possible abuse", "Contraindicated".

                        (used when capturing 'refusal to fill' annotations)
    """
    Actsupplyfulfillmentrefusalreason = ImmunizationStatusReasonCodesCode(
        "_ActSupplyFulfillmentRefusalReason"
    )
    """
    Definition:Specifies the reason that an event occurred in a clinical research study.
    """
    Clinicalresearcheventreason = ImmunizationStatusReasonCodesCode(
        "_ClinicalResearchEventReason"
    )
    """
    Definition:SSpecifies the reason that a test was performed or observation collected in a clinical research study.

                        
                           Note:This set of codes are not strictly reasons, but are used in the currently Normative standard.  Future revisions of the specification will model these as ActRelationships and thes codes may subsequently be retired.  Thus, these codes should not be used for new specifications.
    """
    Clinicalresearchobservationreason = ImmunizationStatusReasonCodesCode(
        "_ClinicalResearchObservationReason"
    )
    """
    Description:Indicates why the prescription should be suspended.
    """
    Combinedpharmacyordersuspendreasoncode = ImmunizationStatusReasonCodesCode(
        "_CombinedPharmacyOrderSuspendReasonCode"
    )
    """
    Description:Identifies reasons for nullifying (retracting) a particular control act.
    """
    Controlactnullificationreasoncode = ImmunizationStatusReasonCodesCode(
        "_ControlActNullificationReasonCode"
    )
    """
    Description: Reasons to refuse a transaction to be undone.
    """
    Controlactnullificationrefusalreasontype = ImmunizationStatusReasonCodesCode(
        "_ControlActNullificationRefusalReasonType"
    )
    """
    Identifies why a specific query, request, or other trigger event occurred.
    """
    Controlactreason = ImmunizationStatusReasonCodesCode("_ControlActReason")
    """
    Description:Identifies why a change is being made to a  record.
    """
    Genericupdatereasoncode = ImmunizationStatusReasonCodesCode(
        "_GenericUpdateReasonCode"
    )
    """
    Definition:A collection of concepts identifying why the patient's profile is being queried.
    """
    PatientProfileQueryReason = ImmunizationStatusReasonCodesCode(
        "_PatientProfileQueryReasonCode"
    )
    """
    Definition:Indicates why the request to transfer a prescription from one dispensing facility to another has been refused.
    """
    Pharmacysupplyrequestfulfillerrevisionrefusalreasoncode = (
        ImmunizationStatusReasonCodesCode(
            "_PharmacySupplyRequestFulfillerRevisionRefusalReasonCode"
        )
    )
    """
    Description: Identifies why a request to add (or activate) a record is being refused.  Examples include the receiving system not able to match the identifier and find that record in the receiving system, having no permission, or a detected issue exists which precludes the requested action.
    """
    Refusalreasoncode = ImmunizationStatusReasonCodesCode("_RefusalReasonCode")
    """
    Reasons for cancelling or rescheduling an Appointment
    """
    Schedulingactreason = ImmunizationStatusReasonCodesCode("_SchedulingActReason")
    """
    Indicates why the act revision (status update) is being refused.
    """
    Statusrevisionrefusalreasoncode = ImmunizationStatusReasonCodesCode(
        "_StatusRevisionRefusalReasonCode"
    )
    """
    Definition:Indicates why the requested authorization to prescribe or dispense a medication has been refused.
    """
    Substanceadministrationpermissionrefusalreasoncode = (
        ImmunizationStatusReasonCodesCode(
            "_SubstanceAdministrationPermissionRefusalReasonCode"
        )
    )
    """
    Reasons why substitution of a substance administration request is not permitted.
    """
    Substanceadminsubstitutionnotallowedreason = ImmunizationStatusReasonCodesCode(
        "_SubstanceAdminSubstitutionNotAllowedReason"
    )
    """
    SubstanceAdminSubstitutionReason
    """
    Substanceadminsubstitutionreason = ImmunizationStatusReasonCodesCode(
        "_SubstanceAdminSubstitutionReason"
    )
    """
    The explanation for why a patient is moved from one location to another within the organization
    """
    Transferactreason = ImmunizationStatusReasonCodesCode("_TransferActReason")
    """
    Definition: This domain is used to document reasons for providing a billable service; the billable services may include both clinical services and social services.
    """
    Actbillableservicereason = ImmunizationStatusReasonCodesCode(
        "_ActBillableServiceReason"
    )
    """
    None
    """
    Bonus = ImmunizationStatusReasonCodesCode("BONUS")
    """
    Description:The level of coverage under the policy or program is available only to children
    """
    ChildrenOnly = ImmunizationStatusReasonCodesCode("CHD")
    """
    Description:The level of coverage under the policy or program is available only to a subscriber's dependents.
    """
    DependentsOnly = ImmunizationStatusReasonCodesCode("DEP")
    """
    Description:The level of coverage under the policy or program is available to an employee and his or her children.
    """
    EmployeeAndChildren = ImmunizationStatusReasonCodesCode("ECH")
    """
    None
    """
    Edu = ImmunizationStatusReasonCodesCode("EDU")
    """
    Description:The level of coverage under the policy or program is available only to an employee.
    """
    EmployeeOnly = ImmunizationStatusReasonCodesCode("EMP")
    """
    Description:The level of coverage under the policy or program is available to an employee and his or her spouse.
    """
    EmployeeAndSpouse = ImmunizationStatusReasonCodesCode("ESP")
    """
    Description:The level of coverage under the policy or program is available to a subscriber's family.
    """
    Family = ImmunizationStatusReasonCodesCode("FAM")
    """
    Description:The level of coverage under the policy or program is available to an individual.
    """
    Individual = ImmunizationStatusReasonCodesCode("IND")
    """
    None
    """
    Invoice = ImmunizationStatusReasonCodesCode("INVOICE")
    """
    None
    """
    Proa = ImmunizationStatusReasonCodesCode("PROA")
    """
    None
    """
    Recov = ImmunizationStatusReasonCodesCode("RECOV")
    """
    None
    """
    Retro = ImmunizationStatusReasonCodesCode("RETRO")
    """
    Description:The level of coverage under the policy or program is available to a subscriber's spouse and children
    """
    SpouseAndChildren = ImmunizationStatusReasonCodesCode("SPC")
    """
    Description:The level of coverage under the policy or program is available only to a subscribers spouse
    """
    SpouseOnly = ImmunizationStatusReasonCodesCode("SPO")
    """
    None
    """
    Tran = ImmunizationStatusReasonCodesCode("TRAN")
    """
    None
    """
    IMMUNE = ImmunizationStatusReasonCodesCode("IMMUNE")
    """
    None
    """
    MEDPREC = ImmunizationStatusReasonCodesCode("MEDPREC")
    """
    None
    """
    OSTOCK = ImmunizationStatusReasonCodesCode("OSTOCK")
    """
    None
    """
    PATOBJ = ImmunizationStatusReasonCodesCode("PATOBJ")
