from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.FhirValueSetBase import FhirValueSetBase
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class MeasureTypeCode(FhirValueSetBase):
    """
    MeasureType
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/ValueSet/measure-type
    """
    codeset: FhirUri = "http://hl7.org/fhir/ValueSet/measure-type"


class MeasureTypeCodeValues:
    """
    A measure which focuses on a process which leads to a certain outcome, meaning that a scientific basis exists for believing that the process, when executed well, will increase the probability of achieving a desired outcome.
    """

    Process = MeasureTypeCode("process")
    """
    A measure that indicates the result of the performance (or non-performance) of a function or process.
    """
    Outcome = MeasureTypeCode("outcome")
    """
    A measure that focuses on a health care provider's capacity, systems, and processes to provide high-quality care.
    """
    Structure = MeasureTypeCode("structure")
    """
    A measure that focuses on patient-reported information such as patient engagement or patient experience measures.
    """
    PatientReportedOutcome = MeasureTypeCode("patient-reported-outcome")
    """
    A measure that combines multiple component measures in to a single quality measure.
    """
    Composite = MeasureTypeCode("composite")
